@@ -30,10 +30,6 @@ class AddColumnStepPerformer(StepPerformer):
     @classmethod
     def step_display_name(cls) -> str:
         return 'Added a Column'
-    
-    @classmethod
-    def step_event_type(cls) -> str:
-        return 'add_column_edit'
 
     @classmethod
     def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
@@ -57,7 +53,7 @@ class AddColumnStepPerformer(StepPerformer):
             raise make_column_exists_error(column_header)
 
         # We add a new step with the added column
-        post_state = deepcopy(prev_state)
+        post_state = prev_state.copy(deep_sheet_indexes=[sheet_index])
 
         # If the column_header_index is out of range, then make the new column the last column
         if column_header_index < 0 or len(prev_state.dfs[sheet_index].columns) <= column_header_index:
