@@ -4,6 +4,7 @@
 # Copyright (c) Saga Inc.
 # Distributed under the terms of the GPL License.
 from copy import deepcopy
+from time import perf_counter
 from typing import Any, Dict, List, Optional, Set, Tuple
 
 import pandas as pd
@@ -37,10 +38,6 @@ class SetColumnFormulaStepPerformer(StepPerformer):
     @classmethod
     def step_display_name(cls) -> str:
         return 'Set Column Formula'
-    
-    @classmethod
-    def step_event_type(cls) -> str:
-        return 'set_column_formula_edit'
 
     @classmethod
     def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
@@ -119,12 +116,14 @@ class SetColumnFormulaStepPerformer(StepPerformer):
             raise make_circular_reference_error(error_modal=False)
 
         # We check out a new step
-        post_state = deepcopy(prev_state)
+        post_state = prev_state.copy(deep_sheet_indexes=[sheet_index])
 
         # Update the column formula, and then execute the new formula graph
         try:
             post_state.column_spreadsheet_code[sheet_index][column_id] = new_formula
+            pandas_start_time = perf_counter()
             refresh_dependant_columns(post_state, post_state.dfs[sheet_index], sheet_index, column_id)
+            pandas_processing_time = perf_counter() - pandas_start_time
         except MitoError as e:
             # Catch the error and make sure that we don't set the error modal
             e.error_modal = False
@@ -132,7 +131,9 @@ class SetColumnFormulaStepPerformer(StepPerformer):
         except:
             raise make_execution_error(error_modal=False)
 
-        return post_state, None
+        return post_state, {
+            'pandas_processing_time': pandas_processing_time
+        }
 
     @classmethod
     def transpile( # type: ignore
